# Donkey Kong: Bird Island
Donkey Kong: Bird Island is a platform game based on T-Rex game.

# Installation
Donkey Kong: Bird Island requires that you have ***Python 3.6+*** and ***pip*** already installed on your computer. To install, type:

```
pip install dkbirdisland
```

To start the game:

```
dkbirdisland
```

# Game Controls
  🡑 Jump <br>
  🡓 Fall faster
